@@ -31,6 +31,8 @@ gnutls_session session;
 bool using_tls = false;
 #endif
 
+char *b64cbtlsunique = NULL;
+
 struct gengetopt_args_info args_info;
 int sockfd = 0;
 
@@ -569,7 +571,8 @@ main (int argc, char *argv[])
 		   gnutls_strerror (res), err_pos);
 	}
 
-      gnutls_transport_set_ptr (session, (gnutls_transport_ptr) sockfd);
+      gnutls_transport_set_ptr (session, (gnutls_transport_ptr)
+				(unsigned long) sockfd);
 
       if (!starttls ())
 	return 1;
@@ -603,6 +606,24 @@ main (int argc, char *argv[])
 		   _("could not verify server certificate (rc=%d)"), status);
 	}
 
+#if HAVE_GNUTLS_SESSION_CHANNEL_BINDING
+	{
+	  gnutls_datum cb;
+
+	  res = gnutls_session_channel_binding (session,
+						GNUTLS_CB_TLS_UNIQUE,
+						&cb);
+	  if (res != GNUTLS_E_SUCCESS)
+	    error (EXIT_FAILURE, 0, _("getting channel binding failed: %s"),
+		   gnutls_strerror (res));
+
+	  res = gsasl_base64_to ((char *) cb.data, cb.size,
+				 &b64cbtlsunique, NULL);
+	  if (res != GSASL_OK)
+	    error (EXIT_FAILURE, 0, "%s", gsasl_strerror (res));
+	}
+#endif
+
       using_tls = true;
     }
 #endif
@@ -847,7 +868,7 @@ main (int argc, char *argv[])
 		  sockalloc = 0;
 		  sockalloc1 = 1000;
 
-		  printf("%.*s", output_len, out);
+		  printf("%.*s", (int) output_len, out);
 		  free (out);
 		}
 	      /* If there was an error, quit.  */
